@@ -1,7 +1,13 @@
 from collections import defaultdict
 from datetime import datetime
 
-from .items import get_collection, get_item, parse_data
+from .items import (
+    get_collection,
+    get_item,
+    get_item_by_code,
+    items_for_collection,
+    parse_data,
+)
 from .models import Settings
 from .sheet_transform import get_col_item_needs, get_no_hide_collections, get_rows
 
@@ -34,6 +40,12 @@ def get_settings(sheet_name=None):
 
     important, unimportant = get_important(rows)
 
+    # always mark weekly items as important
+    weekly_items = items_for_collection('Weekly', items)
+    for item in weekly_items:
+        item_in_orig_coll = get_item_by_code(item.code, items)
+        important.add(item_in_orig_coll)
+
     unimportant |= items - important
 
     unimportant = remove_no_hide_cols(unimportant, rows)
@@ -45,6 +57,7 @@ def get_export_filename():
     now = datetime.now()
     return now.strftime('%Y-%m-%d_%H-%M-%S.json')
 
+
 def write_export(export_path):
     path = export_path / get_export_filename()
 
